@@ -1,3 +1,5 @@
+from functools import partial
+
 from pipetools.debug import get_name, set_name, repr_args
 from pipetools.debug import pipe_exception_handler
 
@@ -48,6 +50,10 @@ class Pipe(object):
     def __call__(self, *args, **kwargs):
         return self.func(*args, **kwargs)
 
+    def __get__(self, instance, owner):
+        return partial(self, instance) if instance else self
+
+
 pipe = Pipe()
 
 
@@ -160,6 +166,9 @@ class XObject(object):
     def __mul__(self, other):
         return self.bind('X * {0!r}'.format(other), lambda x: x * other)
 
+    def __div__(self, other):
+        return self.bind('X / {0!r}'.format(other), lambda x: x / other)
+
     def __add__(self, other):
         return self.bind('X + {0!r}'.format(other), lambda x: x + other)
 
